==> ponyc-0.13.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/collections-persistent-HashMap.md <==
# HashMap\[K: [Any](builtin-Any) #share, V: [Any](builtin-Any) #share, H: [HashFunction](collections-HashFunction)\[K #share\] val\]

A persistent map based on the Compressed Hash Array Mapped Prefix-tree from
'Optimizing Hash-Array Mapped Tries for Fast and Lean Immutable JVM
Collections' by Michael J. Steindorfer and Jurgen J. Vinju

## Usage
```
let empty: Map[String,U32] = Maps.empty[String,U32]() // {}
// Update returns a new map with the provided key set
// to the provided value. The old map is unchanged.
let m2 = m1("a") = 5 // {a: 5}
let m3 = m2("b") = 10 // {a: 5, b: 10}
let m4 = m3.remove("a") // {b: 10}
// You can create a new map from key value pairs.
let map = Maps.from[String,U32]([("a", 2), ("b", 3)]) // {a: 2, b: 3}
```


```pony
class val HashMap[K: Any #share, V: Any #share, H: HashFunction[K #share] val]
```

## Constructors

### create

```pony
new val create()
: HashMap[K #share, V #share, H val] val^
```

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val^

---

### _create

```pony
new val _create(
  r: _MapNode[K #share, V #share, H val] val,
  s: USize val)
: HashMap[K #share, V #share, H val] val^
```
#### Parameters

*   r: [_MapNode](collections-persistent-_MapNode)\[K #share, V #share, H val\] val
*   s: [USize](builtin-USize) val

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val^

---

## Public Functions

### apply

Attempt to get the value corresponding to k.


```pony
fun val apply(
  k: K #share)
: V #share ?
```
#### Parameters

*   k: K #share

#### Returns

* V #share ?

---

### size

Return the amount of key-value pairs in the Map.


```pony
fun val size()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### update

Update the value associated with the provided key.


```pony
fun val update(
  key: K #share,
  value: V #share)
: HashMap[K #share, V #share, H val] val
```
#### Parameters

*   key: K #share
*   value: V #share

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val

---

### remove

Try to remove the provided key from the Map.


```pony
fun val remove(
  k: K #share)
: HashMap[K #share, V #share, H val] val ?
```
#### Parameters

*   k: K #share

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val ?

---

### get_or_else

Get the value associated with provided key if present. Otherwise,
return the provided alternate value.


```pony
fun val get_or_else(
  k: K #share,
  alt: V #share)
: V #share
```
#### Parameters

*   k: K #share
*   alt: V #share

#### Returns

* V #share

---

### contains

Check whether the node contains the provided key.


```pony
fun val contains(
  k: K #share)
: Bool val
```
#### Parameters

*   k: K #share

#### Returns

* [Bool](builtin-Bool) val

---

### concat

Add the K, V pairs from the given iterator to the map.


```pony
fun val concat(
  iter: Iterator[(K #share , V #share)] ref)
: HashMap[K #share, V #share, H val] val
```
#### Parameters

*   iter: [Iterator](builtin-Iterator)\[(K #share , V #share)\] ref

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val

---

### keys

```pony
fun val keys()
: MapKeys[K #share, V #share, H val] ref
```

#### Returns

* [MapKeys](collections-persistent-MapKeys)\[K #share, V #share, H val\] ref

---

### values

```pony
fun val values()
: MapValues[K #share, V #share, H val] ref
```

#### Returns

* [MapValues](collections-persistent-MapValues)\[K #share, V #share, H val\] ref

---

### pairs

```pony
fun val pairs()
: MapPairs[K #share, V #share, H val] ref
```

#### Returns

* [MapPairs](collections-persistent-MapPairs)\[K #share, V #share, H val\] ref

---

## Private Functions

### _root_node

```pony
fun box _root_node()
: _MapNode[K #share, V #share, H val] val
```

#### Returns

* [_MapNode](collections-persistent-_MapNode)\[K #share, V #share, H val\] val

---

==> ponyc-0.15.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/collections-persistent-HashMap.md <==
# HashMap\[K: [Any](builtin-Any) #share, V: [Any](builtin-Any) #share, H: [HashFunction](collections-HashFunction)\[K #share\] val\]

A persistent map based on the Compressed Hash Array Mapped Prefix-tree from
'Optimizing Hash-Array Mapped Tries for Fast and Lean Immutable JVM
Collections' by Michael J. Steindorfer and Jurgen J. Vinju

## Usage
```
let empty = Map[String,U32] // {}
// Update returns a new map with the provided key set
// to the provided value. The old map is unchanged.
let m2 = m1("a") = 5 // {a: 5}
let m3 = m2("b") = 10 // {a: 5, b: 10}
let m4 = m3.remove("a") // {b: 10}
// You can create a new map from key value pairs.
let m5 = Map[String,U32].concat([("a", 2), ("b", 3)].values()) // {a: 2, b: 3}
```


```pony
class val HashMap[K: Any #share, V: Any #share, H: HashFunction[K #share] val]
```

## Constructors

### create

```pony
new val create()
: HashMap[K #share, V #share, H val] val^
```

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val^

---

### _create

```pony
new val _create(
  r: _MapNode[K #share, V #share, H val] val,
  s: USize val)
: HashMap[K #share, V #share, H val] val^
```
#### Parameters

*   r: [_MapNode](collections-persistent-_MapNode)\[K #share, V #share, H val\] val
*   s: [USize](builtin-USize) val

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val^

---

## Public Functions

### apply

Attempt to get the value corresponding to k.


```pony
fun val apply(
  k: K #share)
: V #share ?
```
#### Parameters

*   k: K #share

#### Returns

* V #share ?

---

### size

Return the amount of key-value pairs in the Map.


```pony
fun val size()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### update

Update the value associated with the provided key.


```pony
fun val update(
  key: K #share,
  value: V #share)
: HashMap[K #share, V #share, H val] val
```
#### Parameters

*   key: K #share
*   value: V #share

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val

---

### remove

Try to remove the provided key from the Map.


```pony
fun val remove(
  k: K #share)
: HashMap[K #share, V #share, H val] val ?
```
#### Parameters

*   k: K #share

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val ?

---

### get_or_else

Get the value associated with provided key if present. Otherwise,
return the provided alternate value.


```pony
fun val get_or_else(
  k: K #share,
  alt: V #share)
: V #share
```
#### Parameters

*   k: K #share
*   alt: V #share

#### Returns

* V #share

---

### contains

Check whether the node contains the provided key.


```pony
fun val contains(
  k: K #share)
: Bool val
```
#### Parameters

*   k: K #share

#### Returns

* [Bool](builtin-Bool) val

---

### concat

Add the K, V pairs from the given iterator to the map.


```pony
fun val concat(
  iter: Iterator[(K #share , V #share)] ref)
: HashMap[K #share, V #share, H val] val
```
#### Parameters

*   iter: [Iterator](builtin-Iterator)\[(K #share , V #share)\] ref

#### Returns

* [HashMap](collections-persistent-HashMap)\[K #share, V #share, H val\] val

---

### keys

```pony
fun val keys()
: MapKeys[K #share, V #share, H val] ref
```

#### Returns

* [MapKeys](collections-persistent-MapKeys)\[K #share, V #share, H val\] ref

---

### values

```pony
fun val values()
: MapValues[K #share, V #share, H val] ref
```

#### Returns

* [MapValues](collections-persistent-MapValues)\[K #share, V #share, H val\] ref

---

### pairs

```pony
fun val pairs()
: MapPairs[K #share, V #share, H val] ref
```

#### Returns

* [MapPairs](collections-persistent-MapPairs)\[K #share, V #share, H val\] ref

---

## Private Functions

### _root_node

```pony
fun box _root_node()
: _MapNode[K #share, V #share, H val] val
```

#### Returns

* [_MapNode](collections-persistent-_MapNode)\[K #share, V #share, H val\] val

---
